%define major 12
%define libname %mklibname exiv2_ %{major}
%define libdev %mklibname exiv2 -d

Summary:	Command line tool to access EXIF data in image files
Name:		exiv2
Version:	0.23
Release:	22
License:	GPLv2+
Group:		Graphics
Url:		http://www.exiv2.org/
Source0:	http://www.exiv2.org/%name-%{version}.tar.gz
#Provides:	libexiv

BuildRequires: doxygen
BuildRequires: graphviz
BuildRequires: python
BuildRequires: xsltproc
BuildRequires: expat-devel
BuildRequires: zlib-devel

%description
Exiv2 is a command line utility to access image metadata:

    * print the Exif metadata of JPEG, TIFF and several RAW image 
      formats as summary info, interpreted values, or the plain data 
      for each tag (a sample is here)
    * print the IPTC metadata of JPEG images
    * print, set and delete the JPEG comment of JPEG images
    * set, add and delete Exif and IPTC metadata of JPEG images
    * adjust the Exif timestamp (that's how it all started...)
    * rename Exif image files according to the Exif timestamp
    * extract, insert and delete Exif metadata, IPTC metadata and JPEG 
      comments
    * extract, insert and delete the thumbnail image embedded in the
      Exif metadata
    * fix the Exif ISO setting of picture taken with Nikon cameras

%package -n %{libname}
Summary:	Library to access EXIF data in image files
Group:		Graphics
Obsoletes:  %{_lib}exiv22 < 0.16-1
 
%description -n %{libname}
libexiv2 is a C++ library to access image metadata. libexiv2 is free
software.

The Exiv2 library provides

    * full read and write access to the Exif and IPTC metadata of
      an image through Exiv2 keys and standard C++ iterators
      (Example1, Example2, Example3, Example4)
    * a smart IPTC implementation that does not affect data that
      programs like Photoshop store in the same image segment
    * Exif MakerNote support:
          o MakerNote tags can be accessed just like any other Exif metadata
          o a sophisticated write algorithm avoids corrupting the MakerNote:
              1) the MakerNote is not re-located if possible at all, and
              2) MakerNote Ifd offsets are re-calculated if the MakerNote 
                 needs to be moved (for known Ifd MakerNotes)
    * extract and delete methods for Exif thumbnails (both, JPEG and TIFF
      thumbnails)
    * set methods for Exif thumbnails (JPEG only, TIFF thumbnails can be
      set from individual tags)
    * complete API documentation (by Doxygen)

%package -n %{libdev}
Summary: 	Headers and links to compile against the "%{libname}" library
Group:		Development/C
Requires: 	%{libname} = %{version}-%{release}
Requires:	multiarch-utils
Provides:	libexiv-devel = %{version}-%{release}
Obsoletes:	%{_lib}exiv2_2-devel

%description -n %{libdev}
This package contains all files which one needs to compile programs using
the "%{libname}" library.

%package doc
Summary: Exiv2 library documentation
Group: Books/Computer books
Conflicts:	%{_lib}exiv2_2-devel
BuildArch:	noarch

%description doc
Exiv2 library documentation.

%prep
%setup -q

%build
#LDFLAGS="$LDFLAGS -module"
%configure2_5x \
	--disable-static \
	--enable-shared
%make
%make update-po -C po
%make doc

%install
%makeinstall_std
find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'
%find_lang exiv2

%files  -f %{name}.lang
%doc COPYING README
%{_bindir}/exiv2
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}*

%files -n %{libdev}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*
%{_includedir}/*

%files doc
%doc doc/ChangeLog doc/cmd.txt doc/html doc/include doc/index.html doc/templates



%changelog
* Mon Jun 25 2012 Alexander Khrukin <akhrukin@mandriva.org> 0.23-22
+ Revision: 806803
- version update 0.23

* Tue Dec 13 2011 Matthew Dawkins <mattydaw@mandriva.org> 0.22-22
+ Revision: 740686
- rebuild
- cleaned up spec
- disabled static build
- removed .la files

  + Andrey Bondrov <abondrov@mandriva.org>
    - Remove clean section and rm -rf buildroot in install section

* Sun Oct 09 2011 Andrey Bondrov <abondrov@mandriva.org> 0.22-1
+ Revision: 703871
- New version 0.22, new library major

* Tue May 03 2011 Oden Eriksson <oeriksson@mandriva.com> 0.21.1-2
+ Revision: 664160
- mass rebuild

* Sun Feb 27 2011 Funda Wang <fwang@mandriva.org> 0.21.1-1
+ Revision: 640609
- update to new version 0.21.1

* Wed Dec 01 2010 Funda Wang <fwang@mandriva.org> 0.21-1mdv2011.0
+ Revision: 604320
- fix BR
- new version 0.21

* Thu Sep 02 2010 Thierry Vignaud <tv@mandriva.org> 0.20-2mdv2011.0
+ Revision: 575202
- let the doc subpackage be noarch

* Tue Aug 03 2010 Emmanuel Andry <eandry@mandriva.org> 0.20-1mdv2011.0
+ Revision: 565526
- New version 0.20
- New major 9

* Wed Dec 30 2009 Frederik Himpe <fhimpe@mandriva.org> 0.19-1mdv2010.1
+ Revision: 484177
- Update to new version 0.19 (new major)

* Thu Jun 25 2009 Frederik Himpe <fhimpe@mandriva.org> 0.18.2-1mdv2010.0
+ Revision: 389178
- update to new version 0.18.2

* Thu Apr 16 2009 Helio Chissini de Castro <helio@mandriva.com> 0.18.1-1mdv2009.1
+ Revision: 367803
- UPgrade to bug fix release fixing digikam reported crashes

* Sat Dec 20 2008 Funda Wang <fwang@mandriva.org> 0.18-1mdv2009.1
+ Revision: 316542
- New verison 0.18

* Mon Jun 23 2008 Tiago Salem <salem@mandriva.com.br> 0.17.1-1mdv2009.0
+ Revision: 228078
- version 0.17.1
- fix CVE-2008-2696

* Fri Jun 20 2008 Helio Chissini de Castro <helio@mandriva.com> 0.17-1mdv2009.0
+ Revision: 227482
- New upstream version
- Moved docs for a separated doc package instead of devel package
- Fixed devel package naming, as new major was making impossible to upgrade

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Feb 05 2008 Anssi Hannula <anssi@mandriva.org> 0.16-3mdv2008.1
+ Revision: 162757
- remove obsoletes on old library

* Sat Jan 26 2008 Anssi Hannula <anssi@mandriva.org> 0.16-2mdv2008.1
+ Revision: 158233
- obsolete old library name

* Fri Jan 25 2008 Marcelo Ricardo Leitner <mrl@mandriva.com> 0.16-1mdv2008.1
+ Revision: 157944
- New stable upstream: 0.16. Closes: #36634

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Nov 26 2007 Thierry Vignaud <tv@mandriva.org> 0.16-0.pre1.3mdv2008.1
+ Revision: 112174
- further improved libification (anssi)

* Mon Nov 26 2007 Thierry Vignaud <tv@mandriva.org> 0.16-0.pre1.2mdv2008.1
+ Revision: 112173
- use more macros
- fix library name (which fixes upgrading from previous bogus packages using a
  wrong major as a side effect)

* Sun Nov 25 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.16-0.pre1.1mdv2008.1
+ Revision: 111869
- Add Expat-devel as BuildRequire
- 0.16 pre1

  + Thierry Vignaud <tv@mandriva.org>
    - do not duplicate description
    - description is not copyright

* Tue Oct 16 2007 Angelo Naselli <anaselli@mandriva.org> 0.15-3mdv2008.1
+ Revision: 98947
- Added documents into developer package

* Tue Sep 18 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.15-2mdv2008.0
+ Revision: 89634
- rebuild

* Mon Aug 27 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 0.15-1mdv2008.0
+ Revision: 71867
- New upstream: 0.15

* Fri Apr 20 2007 Angelo Naselli <anaselli@mandriva.org> 0.14-1mdv2008.0
+ Revision: 16204
- new version 0.14

